/*
 *  Types/Note.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using System.Xml;
using System.Reflection;
using Incollector.GUI.Widgets;
using Gtk;
using Mono.Unix;


namespace Incollector.DataTypes {

	public class WebAddress : DataType {
		
		protected static Gtk.Entry NameWidget = new Gtk.Entry ();
		protected static Gtk.Entry UrlWidget  = new Gtk.Entry ();
		
		protected string _DataName;
		protected string _DataURL;

		
		protected string DataName {
			get { return this._DataName;  }
			set { this._DataName = value; }
		}
		
		protected string DataURL {
			get { return this._DataURL;  }
			set { this._DataURL = value; }
		}
		
		
		
		public override string Name {
			get { return "webaddress"; }
		}
		
		public override string Title {
			get { return Catalog.GetString ("Web address"); }
		}
		
		public override string MenuText {
			get { return Catalog.GetString ("Add a web address"); }
		}
		
		public override Gtk.Widget DefaultFocusWidget {
			get { return NameWidget; }
		}
		
		public override Gtk.Widget FocusWidget {
			get { return NameWidget; }
		}
		
		public override Gtk.Widget EditWidget {
			get {
				Gtk.Table tbl = new Gtk.Table (2, 2, false);
				
				Gtk.Label lbl1 = new Gtk.Label (Catalog.GetString ("Name"));
				lbl1.Xalign = 1;
				lbl1.Yalign = (float) 0.50;
				tbl.Attach (lbl1, 0, 1, 0, 1, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				NameWidget = new Gtk.Entry ();
				NameWidget.Text = this._DataName;
				tbl.Attach (NameWidget, 1, 2, 0, 1,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Shrink | AttachOptions.Fill, 3, 3);
				
				Gtk.Label lbl2 = new Gtk.Label (Catalog.GetString ("URL"));
				lbl2.Xalign = 1;
				lbl2.Yalign = (float) 0.50;
				tbl.Attach (lbl2, 0, 1, 1, 2, AttachOptions.Fill,
							AttachOptions.Fill, 3, 3);
				
				UrlWidget  = new Gtk.Entry ();
				UrlWidget.Text = this._DataURL;
				tbl.Attach (UrlWidget, 1, 2, 1, 2,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Shrink | AttachOptions.Fill, 3, 3);
				
				tbl.ShowAll ();
				
				return tbl;
			}
		}
		
		public override string EditWidgetContent {
			set { UrlWidget.Text = value; }
		}
		
		public override Gtk.Widget PreviewWidget {
			get {
				Gtk.Table tbl = new Gtk.Table (2, 2, false);
				
				Gtk.Label lbl1 = new Gtk.Label ();
				lbl1.CanFocus = true;
				lbl1.UseMarkup = true;
				lbl1.Markup    = "<b>" + Catalog.GetString ("Name") + "</b>";
				lbl1.Xalign    = 1;
				lbl1.Yalign     = (float) 0.00;
				tbl.Attach (lbl1, 0, 1, 0, 1, AttachOptions.Fill, AttachOptions.Fill, 3, 3);
				
				PreviewLabel Title  = new PreviewLabel (this.DataName);
				Title.Xalign     = 0;
				Title.Yalign     = (float) 0.00;
				tbl.Attach (Title, 1, 2, 0, 1, AttachOptions.Fill, AttachOptions.Fill, 3, 3);
				
				Gtk.Label lbl2 = new Gtk.Label ();
				lbl2.CanFocus = false;
				lbl2.UseMarkup = true;
				lbl2.Markup    = "<b>" + Catalog.GetString ("URL") + "</b>";
				lbl2.Xalign    = 1;
				lbl2.Yalign    = (float) 0.00;
				tbl.Attach (lbl2, 0, 1, 1, 2, AttachOptions.Fill, AttachOptions.Fill, 3, 3);
				
				Incollector.GUI.Widgets.LinkLabel URL = new Incollector.GUI.Widgets.LinkLabel (this.DataURL);
				URL.CanFocus = false;
				URL.Yalign    = (float) 0.00;
				tbl.Attach (URL, 1, 2, 1, 2,
							AttachOptions.Expand | AttachOptions.Fill,
							AttachOptions.Expand | AttachOptions.Fill, 3, 3);
				
				tbl.ShowAll ();
				
				return tbl;
			}
		}
		
		public override string EntryTitle {
			get { return this.DataName + " (" + this.DataURL + ")"; }
		}
		
		public override Gdk.Pixbuf Icon16 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "webaddress-16.png"); }
		}
		
		public override Gdk.Pixbuf Icon32 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "webaddress-32.png"); }
		}
		
		public override Gdk.Pixbuf Icon48 {
			get { return new Gdk.Pixbuf (Assembly.GetEntryAssembly (), "webaddress-48.png"); }
		}
		
		
		
		
		public WebAddress ()
		{
			this._DataName = "";
			this._DataURL  = "";
		}
		
		
		public override DataType New ()
		{
			return new WebAddress ();
		}
		
		
		public override DataType Clone ()
		{
			WebAddress addr = new WebAddress ();
			
			addr._DataName = this._DataName.Clone () as string;
			addr._DataURL = this._DataURL.Clone () as string;
			
			return addr;
		}


		public override void ReadXml (XmlTextReader reader)
		{
			this.DataName = reader.GetAttribute ("name");
			this.DataURL  = reader.ReadString ();
		}
		
		
		public override void WriteXml (XmlTextWriter writer)
		{
			writer.WriteStartElement (Name);
				writer.WriteAttributeString ("name", this.DataName);
				writer.WriteString (this.DataURL);
			writer.WriteEndElement ();
		}
		
		
		public override void AddChangedEvent (EventHandler hdlr)
		{
			NameWidget.Changed += hdlr;
			UrlWidget.Changed  += hdlr;
		}
		
		
		public override bool Search (string query)
		{
			return Engine.Text.Search (query, this.DataName) || Engine.Text.Search (query, this.DataURL);
		}
		
		
		public override bool IsFormFilledIn ()
		{
			return (NameWidget.Text != "") && (UrlWidget.Text != "");
		}
		
		
		public override void SynchronizeData ()
		{
			this._DataName = NameWidget.Text;
			this._DataURL  = UrlWidget.Text;
		}

	}
}
